@@ -24,14 +24,20 @@ import (
 
 const brewConfigExtra = "BrewConfig"
 
-var (
-	// ErrNoArchivesFound happens when 0 archives are found.
-	ErrNoArchivesFound = errors.New("no linux/macos archives found")
+// ErrMultipleArchivesSameOS happens when the config yields multiple archives
+// for linux or windows.
+var ErrMultipleArchivesSameOS = errors.New("one tap can handle only archive of an OS/Arch combination. Consider using ids in the brew section")
 
-	// ErrMultipleArchivesSameOS happens when the config yields multiple archives
-	// for linux or windows.
-	ErrMultipleArchivesSameOS = errors.New("one tap can handle only archive of an OS/Arch combination. Consider using ids in the brew section")
-)
+// ErrNoArchivesFound happens when 0 archives are found.
+type ErrNoArchivesFound struct {
+	goarm   string
+	goamd64 string
+	ids     []string
+}
+
+func (e ErrNoArchivesFound) Error() string {
+	return fmt.Sprintf("no linux/macos archives found matching goos=[darwin linux] goarch=[amd64 arm64 arm] goamd64=%s goarm=%s ids=%v", e.goamd64, e.goarm, e.ids)
+}
 
 // Pipe for brew deployment.
 type Pipe struct{}
@@ -147,7 +153,22 @@ func doPublish(ctx *context.Context, formula *artifact.Artifact, cl client.Clien
 		return err
 	}
 
-	return cl.CreateFile(ctx, author, repo, content, gpath, msg)
+	if !brew.Tap.PullRequest.Enabled {
+		return cl.CreateFile(ctx, author, repo, content, gpath, msg)
+	}
+
+	log.Info("brews.pull_request enabled, creating a PR")
+	pcl, ok := cl.(client.PullRequestOpener)
+	if !ok {
+		return fmt.Errorf("client does not support pull requests")
+	}
+
+	if err := cl.CreateFile(ctx, author, repo, content, gpath, msg); err != nil {
+		return err
+	}
+
+	title := fmt.Sprintf("Updated %s to %s", ctx.Config.ProjectName, ctx.Version)
+	return pcl.OpenPullRequest(ctx, repo, brew.Tap.PullRequest.Base, title)
 }
 
 func doRun(ctx *context.Context, brew config.Homebrew, cl client.Client) error {
@@ -187,7 +208,11 @@ func doRun(ctx *context.Context, brew config.Homebrew, cl client.Client) error {
 
 	archives := ctx.Artifacts.Filter(artifact.And(filters...)).List()
 	if len(archives) == 0 {
-		return ErrNoArchivesFound
+		return ErrNoArchivesFound{
+			goamd64: brew.Goamd64,
+			goarm:   brew.Goarm,
+			ids:     brew.IDs,
+		}
 	}
 
 	name, err := tmpl.New(ctx).Apply(brew.Name)
@@ -247,9 +272,6 @@ func buildFormula(ctx *context.Context, brew config.Homebrew, client client.Clie
 func doBuildFormula(ctx *context.Context, data templateData) (string, error) {
 	t, err := template.
 		New(data.Name).
-		Funcs(template.FuncMap{
-			"join": strings.Join,
-		}).
 		Parse(formulaTemplate)
 	if err != nil {
 		return "", err
@@ -282,9 +304,13 @@ func doBuildFormula(ctx *context.Context, data templateData) (string, error) {
 	return out.String(), nil
 }
 
-func installs(cfg config.Homebrew, art *artifact.Artifact) []string {
-	if cfg.Install != "" {
-		return split(cfg.Install)
+func installs(ctx *context.Context, cfg config.Homebrew, art *artifact.Artifact) ([]string, error) {
+	applied, err := tmpl.New(ctx).WithArtifact(art).Apply(cfg.Install)
+	if err != nil {
+		return nil, err
+	}
+	if applied != "" {
+		return split(applied), nil
 	}
 
 	install := map[string]bool{}
@@ -302,7 +328,7 @@ func installs(cfg config.Homebrew, art *artifact.Artifact) []string {
 	result := keys(install)
 	sort.Strings(result)
 	log.Warnf("guessing install to be %q", strings.Join(result, ", "))
-	return result
+	return result, nil
 }
 
 func keys(m map[string]bool) []string {
@@ -346,7 +372,12 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifa
 			cfg.URLTemplate = url
 		}
 
-		url, err := tmpl.New(ctx).WithArtifact(art, map[string]string{}).Apply(cfg.URLTemplate)
+		url, err := tmpl.New(ctx).WithArtifact(art).Apply(cfg.URLTemplate)
+		if err != nil {
+			return result, err
+		}
+
+		install, err := installs(ctx, cfg, art)
 		if err != nil {
 			return result, err
 		}
@@ -357,7 +388,7 @@ func dataFor(ctx *context.Context, cfg config.Homebrew, cl client.Client, artifa
 			OS:               art.Goos,
 			Arch:             art.Goarch,
 			DownloadStrategy: cfg.DownloadStrategy,
-			Install:          installs(cfg, art),
+			Install:          install,
 		}
 
 		counts[pkg.OS+pkg.Arch]++
