@@ -170,6 +170,24 @@ func TestShallowClone(t *testing.T) {
 }
 
 func TestTagSortOrder(t *testing.T) {
+	testlib.Mktmp(t)
+	testlib.GitInit(t)
+	testlib.GitRemoteAdd(t, "git@github.com:foo/bar.git")
+	testlib.GitCommit(t, "commit1")
+	testlib.GitCommit(t, "commit2")
+	testlib.GitCommit(t, "commit3")
+	testlib.GitTag(t, "v0.0.2")
+	testlib.GitTag(t, "v0.0.1")
+	ctx := testctx.NewWithCfg(config.Project{
+		Git: config.Git{
+			TagSort: "-version:refname",
+		},
+	})
+	require.NoError(t, Pipe{}.Run(ctx))
+	require.Equal(t, "v0.0.2", ctx.Git.CurrentTag)
+}
+
+func TestTagSortOrderPrerelease(t *testing.T) {
 	testlib.Mktmp(t)
 	testlib.GitInit(t)
 	testlib.GitRemoteAdd(t, "git@github.com:foo/bar.git")
@@ -180,7 +198,8 @@ func TestTagSortOrder(t *testing.T) {
 	testlib.GitTag(t, "v0.0.1")
 	ctx := testctx.NewWithCfg(config.Project{
 		Git: config.Git{
-			TagSort: "-version:creatordate",
+			TagSort:          "-version:refname",
+			PrereleaseSuffix: "-",
 		},
 	})
 	require.NoError(t, Pipe{}.Run(ctx))
