@@ -6,7 +6,11 @@ import (
 	"runtime"
 	"runtime/debug"
 
+	"github.com/caarlos0/log"
+	"github.com/charmbracelet/lipgloss"
 	"github.com/goreleaser/goreleaser/cmd"
+	"github.com/muesli/termenv"
+	"go.uber.org/automaxprocs/maxprocs"
 )
 
 // nolint: gochecknoglobals
@@ -17,6 +21,18 @@ var (
 	builtBy = ""
 )
 
+func init() {
+	// enable colored output on github actions et al
+	if os.Getenv("CI") != "" {
+		lipgloss.SetColorProfile(termenv.TrueColor)
+	}
+	// automatically set GOMAXPROCS to match available CPUs.
+	// GOMAXPROCS will be used as the default value for the --parallelism flag.
+	if _, err := maxprocs.Set(); err != nil {
+		log.WithError(err).Fatal("failed to set GOMAXPROCS")
+	}
+}
+
 func main() {
 	cmd.Execute(
 		buildVersion(version, commit, date, builtBy),
