@@ -9,6 +9,7 @@ import (
 	"testing"
 	"time"
 
+	"github.com/goreleaser/goreleaser/internal/testlib"
 	"github.com/goreleaser/goreleaser/pkg/config"
 	"github.com/stretchr/testify/require"
 )
@@ -58,6 +59,11 @@ func TestTarFile(t *testing.T) {
 		Destination: "link.txt",
 	}))
 
+	require.ErrorIs(t, archive.Add(config.File{
+		Source:      "../testdata/regular.txt",
+		Destination: "link.txt",
+	}), fs.ErrExist)
+
 	require.NoError(t, archive.Close())
 	require.Error(t, archive.Add(config.File{
 		Source:      "tar.go",
@@ -114,10 +120,10 @@ func TestTarFileInfo(t *testing.T) {
 		Source:      "../testdata/foo.txt",
 		Destination: "nope.txt",
 		Info: config.FileInfo{
-			Mode:  0o755,
-			Owner: "carlos",
-			Group: "root",
-			MTime: now,
+			Mode:        0o755,
+			Owner:       "carlos",
+			Group:       "root",
+			ParsedMTime: now,
 		},
 	}))
 
@@ -158,3 +164,34 @@ func TestTarInvalidLink(t *testing.T) {
 		Destination: "badlink.txt",
 	}))
 }
+
+func TestCopying(t *testing.T) {
+	f1, err := os.Create(filepath.Join(t.TempDir(), "1.tar"))
+	require.NoError(t, err)
+	f2, err := os.Create(filepath.Join(t.TempDir(), "2.tar"))
+	require.NoError(t, err)
+
+	t1 := New(f1)
+	require.NoError(t, t1.Add(config.File{
+		Source:      "../testdata/foo.txt",
+		Destination: "foo.txt",
+	}))
+	require.NoError(t, t1.Close())
+	require.NoError(t, f1.Close())
+
+	f1, err = os.Open(f1.Name())
+	require.NoError(t, err)
+
+	t2, err := Copying(f1, f2)
+	require.NoError(t, err)
+	require.NoError(t, t2.Add(config.File{
+		Source:      "../testdata/sub1/executable",
+		Destination: "executable",
+	}))
+	require.NoError(t, t2.Close())
+	require.NoError(t, f2.Close())
+	require.NoError(t, f1.Close())
+
+	require.Equal(t, []string{"foo.txt"}, testlib.LsArchive(t, f1.Name(), "tar"))
+	require.Equal(t, []string{"foo.txt", "executable"}, testlib.LsArchive(t, f2.Name(), "tar"))
+}
